@@ -1,18 +1,22 @@
-<map version="freeplane 1.2.0">
+<map version="freeplane 1.5.9">
 <!--To view this file, download free mind mapping software Freeplane from http://freeplane.sourceforge.net -->
-<node TEXT="Freeplane&#xa;Functies" FOLDED="false" ID="ID_45488473" CREATED="1288535648658" MODIFIED="1321016216736" BACKGROUND_COLOR="#00ff99" VGAP="0">
+<node TEXT="Freeplane&#xa;Functies" FOLDED="false" ID="ID_45488473" CREATED="1288535648658" MODIFIED="1321016216736" BACKGROUND_COLOR="#00ff99" VGAP_QUANTITY="0.0 px">
 <icon BUILTIN="bee"/>
 <font BOLD="true"/>
 <hook NAME="MapStyle">
-    <properties show_icon_for_attributes="false" show_note_icons="false" show_notes_in_map="false"/>
+    <properties fit_to_viewport="false;" show_icon_for_attributes="false" show_note_icons="false" show_notes_in_map="false"/>
 
 <map_styles>
-<stylenode LOCALIZED_TEXT="styles.root_node">
-<stylenode LOCALIZED_TEXT="styles.predefined" POSITION="right">
-<stylenode LOCALIZED_TEXT="default" COLOR="#000000" STYLE="fork" MAX_WIDTH="600" MIN_WIDTH="1" FORMAT_AS_HYPERLINK="true">
+<stylenode LOCALIZED_TEXT="styles.root_node" STYLE="oval" UNIFORM_SHAPE="true" VGAP_QUANTITY="24.0 pt">
+<font SIZE="24"/>
+<stylenode LOCALIZED_TEXT="styles.predefined" POSITION="right" STYLE="bubble">
+<stylenode LOCALIZED_TEXT="default" FORMAT_AS_HYPERLINK="true" COLOR="#000000" STYLE="fork" MAX_WIDTH="600.0 px" MIN_WIDTH="1.0 px">
 <font NAME="SansSerif" SIZE="8" BOLD="false" ITALIC="false"/>
 </stylenode>
 <stylenode LOCALIZED_TEXT="defaultstyle.details"/>
+<stylenode LOCALIZED_TEXT="defaultstyle.attributes">
+<font SIZE="9"/>
+</stylenode>
 <stylenode LOCALIZED_TEXT="defaultstyle.note"/>
 <stylenode LOCALIZED_TEXT="defaultstyle.floating">
 <edge STYLE="hide_edge"/>
@@ -85,7 +89,7 @@
 <font NAME="Liberation Sans" SIZE="12"/>
 </stylenode>
 </stylenode>
-<stylenode LOCALIZED_TEXT="styles.AutomaticLayout" POSITION="right">
+<stylenode LOCALIZED_TEXT="styles.AutomaticLayout" POSITION="right" STYLE="bubble">
 <stylenode LOCALIZED_TEXT="AutomaticLayout.level.root" COLOR="#000000">
 <font SIZE="20"/>
 </stylenode>
@@ -104,7 +108,7 @@
 <font SIZE="12"/>
 </stylenode>
 </stylenode>
-<stylenode LOCALIZED_TEXT="styles.user-defined" POSITION="right">
+<stylenode LOCALIZED_TEXT="styles.user-defined" POSITION="right" STYLE="bubble">
 <stylenode TEXT="Reference">
 <icon BUILTIN="help"/>
 <edge STYLE="hide_edge"/>
@@ -149,9 +153,8 @@
   </body>
 </html>
 </richcontent>
-<node TEXT="In knoopkern" POSITION="left" ID="ID_1556354626" CREATED="1319792091506" MODIFIED="1323790447061" HGAP="5" VSHIFT="-40" BACKGROUND_COLOR="#ffff00" NUMBERED="true">
+<node TEXT="In knoopkern" POSITION="left" ID="ID_1556354626" CREATED="1319792091506" MODIFIED="1323790447061" HGAP_QUANTITY="5.0 px" VSHIFT_QUANTITY="-40.0 px" BACKGROUND_COLOR="#ffff00" NUMBERED="true">
 <font BOLD="false"/>
-<hook NAME="FirstGroupNode"/>
 <richcontent TYPE="NOTE">
 
 <html>
@@ -186,6 +189,7 @@
     </p>
   </body>
 </html>
+
 </richcontent>
 <richcontent TYPE="NOTE">
 
@@ -210,7 +214,7 @@
 </richcontent>
 <edge STYLE="horizontal" WIDTH="thin"/>
 </node>
-<node ID="ID_300419503" CREATED="1319798221748" MODIFIED="1336132643156" HGAP="363" VSHIFT="-71" STYLE="bubble"><richcontent TYPE="NODE">
+<node ID="ID_300419503" CREATED="1319798221748" MODIFIED="1336132643156" HGAP_QUANTITY="363.0 px" VSHIFT_QUANTITY="-71.0 px" STYLE="bubble"><richcontent TYPE="NODE">
 
 <html>
   <head>
@@ -220,6 +224,7 @@
     <img src="Images/doc/freeplaneApplications.png"/>
   </body>
 </html>
+
 </richcontent>
 <hook NAME="FreeNode"/>
 <edge STYLE="hide_edge"/>
@@ -245,7 +250,7 @@
 </html>
 </richcontent>
 </node>
-<node TEXT="Interne pijl-koppeling, of" ID="ID_1519332680" CREATED="1288542452827" MODIFIED="1323788864205" LINK="#ID_784697063" HGAP="21" VSHIFT="-2" TEXT_SHORTENED="true">
+<node TEXT="Interne pijl-koppeling, of" ID="ID_1519332680" CREATED="1288542452827" MODIFIED="1323788864205" LINK="#ID_784697063" HGAP_QUANTITY="21.0 px" VSHIFT_QUANTITY="-2.0 px" TEXT_SHORTENED="true">
 <edge STYLE="horizontal" WIDTH="thin"/>
 <richcontent TYPE="NOTE">
 
@@ -269,7 +274,7 @@
 </html>
 </richcontent>
 </node>
-<node TEXT="Externe pijl-koppeling, en" ID="ID_1537075496" CREATED="1288542605210" MODIFIED="1323788903922" LINK="http://kioo.nl/" HGAP="21" VSHIFT="-3" TEXT_SHORTENED="true">
+<node TEXT="Externe pijl-koppeling, en" ID="ID_1537075496" CREATED="1288542605210" MODIFIED="1323788903922" LINK="http://kioo.nl/" HGAP_QUANTITY="21.0 px" VSHIFT_QUANTITY="-3.0 px" TEXT_SHORTENED="true">
 <edge STYLE="horizontal" WIDTH="thin"/>
 <richcontent TYPE="NOTE">
 
@@ -293,7 +298,7 @@
 </html>
 </richcontent>
 </node>
-<node TEXT="Pictogrammen" ID="ID_233656995" CREATED="1288542843639" MODIFIED="1323788954544" HGAP="21" VSHIFT="-7" TEXT_SHORTENED="true">
+<node TEXT="Pictogrammen" ID="ID_233656995" CREATED="1288542843639" MODIFIED="1323788954544" HGAP_QUANTITY="21.0 px" VSHIFT_QUANTITY="-7.0 px" TEXT_SHORTENED="true">
 <icon BUILTIN="bookmark"/>
 <icon BUILTIN="button_ok"/>
 <icon BUILTIN="closed"/>
@@ -366,7 +371,7 @@
 <edge STYLE="horizontal" WIDTH="thin"/>
 </node>
 </node>
-<node TEXT="Vrij positioneerbare knoop" POSITION="left" ID="ID_1280208201" CREATED="1319797134021" MODIFIED="1323789119624" HGAP="140" VSHIFT="19" TEXT_SHORTENED="true">
+<node TEXT="Vrij positioneerbare knoop" POSITION="left" ID="ID_1280208201" CREATED="1319797134021" MODIFIED="1323789119624" HGAP_QUANTITY="140.0 px" VSHIFT_QUANTITY="19.0 px" TEXT_SHORTENED="true">
 <hook NAME="FreeNode"/>
 <font BOLD="true"/>
 <richcontent TYPE="NOTE">
@@ -403,7 +408,7 @@
   </body>
 </html>
 </richcontent>
-<node TEXT="Zwevende knoop" LOCALIZED_STYLE_REF="defaultstyle.floating" ID="ID_231217112" CREATED="1319797190586" MODIFIED="1323789155332" VSHIFT="10" TEXT_SHORTENED="true">
+<node TEXT="Zwevende knoop" LOCALIZED_STYLE_REF="defaultstyle.floating" ID="ID_231217112" CREATED="1319797190586" MODIFIED="1323789155332" VSHIFT_QUANTITY="10.0 px" TEXT_SHORTENED="true">
 <font BOLD="true"/>
 <richcontent TYPE="NOTE">
 
@@ -441,7 +446,7 @@
 </richcontent>
 </node>
 </node>
-<node POSITION="right" ID="ID_1077719150" CREATED="1319792123071" MODIFIED="1321038005400" VGAP="0" HGAP="-10" BACKGROUND_COLOR="#ffff00" NUMBERED="true"><richcontent TYPE="NODE">
+<node POSITION="right" ID="ID_1077719150" CREATED="1319792123071" MODIFIED="1321038005400" VGAP_QUANTITY="0.0 px" HGAP_QUANTITY="-10.0 px" BACKGROUND_COLOR="#ffff00" NUMBERED="true"><richcontent TYPE="NODE">
 
 <html>
   <head>
@@ -456,6 +461,7 @@
     </p>
   </body>
 </html>
+
 </richcontent>
 <font BOLD="false"/>
 <richcontent TYPE="NOTE">
@@ -480,7 +486,7 @@
 </html>
 </richcontent>
 <edge STYLE="sharp_bezier" COLOR="#cc0000" WIDTH="2"/>
-<node TEXT="Onder deze knoopkern:" ID="ID_1010722858" CREATED="1288646162992" MODIFIED="1336132660269" STYLE="bubble" VGAP="0" VSHIFT="-9">
+<node TEXT="Onder deze knoopkern:" ID="ID_1010722858" CREATED="1288646162992" MODIFIED="1336132660269" STYLE="bubble" VGAP_QUANTITY="0.0 px" VSHIFT_QUANTITY="-9.0 px">
 <font ITALIC="false"/>
 <attribute NAME="a1" VALUE="waarde 1"/>
 <attribute NAME="a2" VALUE="waarde 2"/>
@@ -500,7 +506,7 @@
 <hook EQUATION="\begin{array}{l}&#xa;\mbox{I}^\fgcolor{ff0000}{\heartsuit}\mbox{\JLaTeXMath}\\&#xa;\end{array}" NAME="plugins/latex/LatexNodeHook.properties"/>
 <edge STYLE="bezier" WIDTH="thin"/>
 <hook URI="Images/doc/freeplaneApplications.png" SIZE="0.51111114" NAME="ExternalObject"/>
-<node STYLE_REF="Reference" ID="ID_965583686" CREATED="1319872918353" MODIFIED="1321010685262" HGAP="280" VSHIFT="-11"><richcontent TYPE="NODE">
+<node STYLE_REF="Reference" ID="ID_965583686" CREATED="1319872918353" MODIFIED="1321010685262" HGAP_QUANTITY="280.0 px" VSHIFT_QUANTITY="-11.0 px"><richcontent TYPE="NODE">
 
 <html>
   <head>
@@ -512,7 +518,9 @@
     </p>
   </body>
 </html>
+
 </richcontent>
+<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_965583686" STARTINCLINATION="-68;21;" ENDINCLINATION="-68;21;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
 <richcontent TYPE="NOTE">
 
 <html>
@@ -536,9 +544,8 @@
 </richcontent>
 <hook NAME="FreeNode"/>
 <font BOLD="false"/>
-<arrowlink SHAPE="CUBIC_CURVE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_965583686" STARTINCLINATION="-68;21;" ENDINCLINATION="-68;21;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
 </node>
-<node ID="ID_242844262" CREATED="1319799725287" MODIFIED="1321011337329" HGAP="390" VSHIFT="39" BACKGROUND_COLOR="#ffff99">
+<node ID="ID_242844262" CREATED="1319799725287" MODIFIED="1321011337329" HGAP_QUANTITY="390.0 px" VSHIFT_QUANTITY="39.0 px" BACKGROUND_COLOR="#ffff99">
 <icon BUILTIN="yes"/>
 <richcontent TYPE="NODE">
 
@@ -555,6 +562,7 @@
     </p>
   </body>
 </html>
+
 </richcontent>
 <hook NAME="FreeNode"/>
 <edge STYLE="hide_edge"/>
@@ -583,7 +591,8 @@
 </html>
 </richcontent>
 </node>
-<node TEXT="Attributen" STYLE_REF="Reference" ID="ID_1546010515" CREATED="1319872918353" MODIFIED="1321038090373" HGAP="260" VSHIFT="59">
+<node TEXT="Attributen" STYLE_REF="Reference" ID="ID_1546010515" CREATED="1319872918353" MODIFIED="1321038090373" HGAP_QUANTITY="260.0 px" VSHIFT_QUANTITY="59.0 px">
+<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1546010515" STARTINCLINATION="-61;0;" ENDINCLINATION="-61;0;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
 <hook NAME="FreeNode"/>
 <richcontent TYPE="NOTE">
 
@@ -609,9 +618,8 @@
   </body>
 </html>
 </richcontent>
-<arrowlink SHAPE="CUBIC_CURVE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1546010515" STARTINCLINATION="-61;0;" ENDINCLINATION="-61;0;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
 </node>
-<node STYLE_REF="Reference" ID="ID_1064212525" CREATED="1319872918353" MODIFIED="1321010842194" HGAP="240" VSHIFT="119"><richcontent TYPE="NODE">
+<node STYLE_REF="Reference" ID="ID_1064212525" CREATED="1319872918353" MODIFIED="1321010842194" HGAP_QUANTITY="240.0 px" VSHIFT_QUANTITY="119.0 px"><richcontent TYPE="NODE">
 
 <html>
   <head>
@@ -623,7 +631,9 @@
     </p>
   </body>
 </html>
+
 </richcontent>
+<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1064212525" STARTINCLINATION="-94;-18;" ENDINCLINATION="-94;-18;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
 <richcontent TYPE="NOTE">
 
 <html>
@@ -647,9 +657,8 @@
 </richcontent>
 <hook NAME="FreeNode"/>
 <font BOLD="false"/>
-<arrowlink SHAPE="CUBIC_CURVE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1064212525" STARTINCLINATION="-94;-18;" ENDINCLINATION="-94;-18;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
 </node>
-<node STYLE_REF="Reference" ID="ID_1639134686" CREATED="1319873881764" MODIFIED="1323790279907" HGAP="-20" VSHIFT="90"><richcontent TYPE="NODE">
+<node STYLE_REF="Reference" ID="ID_1639134686" CREATED="1319873881764" MODIFIED="1323790279907" HGAP_QUANTITY="-20.0 px" VSHIFT_QUANTITY="90.0 px"><richcontent TYPE="NODE">
 
 <html>
   <head>
@@ -661,7 +670,9 @@
     </p>
   </body>
 </html>
+
 </richcontent>
+<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1639134686" STARTINCLINATION="-108;-23;" ENDINCLINATION="-108;-23;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
 <font BOLD="false"/>
 <richcontent TYPE="NOTE">
 
@@ -684,9 +695,8 @@
   </body>
 </html>
 </richcontent>
-<arrowlink SHAPE="CUBIC_CURVE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1639134686" STARTINCLINATION="-108;-23;" ENDINCLINATION="-108;-23;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
 </node>
-<node ID="ID_1802101455" CREATED="1319799725287" MODIFIED="1321016344016" HGAP="200" VSHIFT="209" BACKGROUND_COLOR="#ffff99">
+<node ID="ID_1802101455" CREATED="1319799725287" MODIFIED="1321016344016" HGAP_QUANTITY="200.0 px" VSHIFT_QUANTITY="209.0 px" BACKGROUND_COLOR="#ffff99">
 <icon BUILTIN="yes"/>
 <richcontent TYPE="NODE">
 
@@ -703,13 +713,18 @@
     </p>
   </body>
 </html>
+
 </richcontent>
+<arrowlink SHAPE="LINE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1802101455" STARTINCLINATION="-53;-31;" ENDINCLINATION="-53;-31;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
 <edge STYLE="hide_edge"/>
 <hook NAME="FreeNode"/>
-<arrowlink SHAPE="CUBIC_CURVE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1802101455" STARTINCLINATION="-53;-31;" ENDINCLINATION="-53;-31;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
 </node>
 </node>
-<node TEXT="Takken" STYLE_REF="Reference" FOLDED="true" ID="ID_1944496966" CREATED="1319872918353" MODIFIED="1321010423422" HGAP="-60" VSHIFT="-91"><richcontent TYPE="NOTE">
+<node TEXT="Takken" STYLE_REF="Reference" FOLDED="true" ID="ID_1944496966" CREATED="1319872918353" MODIFIED="1321010423422" HGAP_QUANTITY="-60.0 px" VSHIFT_QUANTITY="-91.0 px">
+<arrowlink SHAPE="LINE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1944496966" STARTINCLINATION="-28;99;" ENDINCLINATION="-28;99;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
+<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1944496966" STARTINCLINATION="120;32;" ENDINCLINATION="120;32;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
+<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1944496966" STARTINCLINATION="-121;31;" ENDINCLINATION="-121;31;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
+<richcontent TYPE="NOTE">
 
 <html>
   <head>
@@ -731,35 +746,31 @@
 </html>
 </richcontent>
 <hook NAME="FreeNode"/>
-<arrowlink SHAPE="CUBIC_CURVE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1944496966" STARTINCLINATION="120;32;" ENDINCLINATION="120;32;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
-<arrowlink SHAPE="CUBIC_CURVE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1944496966" STARTINCLINATION="-121;31;" ENDINCLINATION="-121;31;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
-<arrowlink SHAPE="CUBIC_CURVE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1944496966" STARTINCLINATION="-28;99;" ENDINCLINATION="-28;99;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
-<node TEXT="Opmaken tak" ID="ID_1601648824" CREATED="1319796287461" MODIFIED="1321037919116" HGAP="30" VSHIFT="-172">
+<node TEXT="Opmaken tak" ID="ID_1601648824" CREATED="1319796287461" MODIFIED="1321037919116" HGAP_QUANTITY="30.0 px" VSHIFT_QUANTITY="-172.0 px">
 <edge STYLE="bezier"/>
-<node TEXT="dikte tak" ID="ID_241458321" CREATED="1288541466835" MODIFIED="1288646970331" VSHIFT="7">
-<node TEXT="dun" ID="ID_1693976270" CREATED="1288541473878" MODIFIED="1288541507504" HGAP="42"/>
-<node TEXT="punt 3" ID="ID_1152182019" CREATED="1288542920337" MODIFIED="1288542944097" HGAP="42" VSHIFT="9">
+<node TEXT="dikte tak" ID="ID_241458321" CREATED="1288541466835" MODIFIED="1288646970331" VSHIFT_QUANTITY="7.0 px">
+<node TEXT="dun" ID="ID_1693976270" CREATED="1288541473878" MODIFIED="1288541507504" HGAP_QUANTITY="42.0 px"/>
+<node TEXT="punt 3" ID="ID_1152182019" CREATED="1288542920337" MODIFIED="1288542944097" HGAP_QUANTITY="42.0 px" VSHIFT_QUANTITY="9.0 px">
 <edge WIDTH="2"/>
 </node>
-<node TEXT="punt 8" ID="ID_1828139471" CREATED="1288541479345" MODIFIED="1288542967746" HGAP="42" VSHIFT="5">
+<node TEXT="punt 8" ID="ID_1828139471" CREATED="1288541479345" MODIFIED="1288542967746" HGAP_QUANTITY="42.0 px" VSHIFT_QUANTITY="5.0 px">
 <edge WIDTH="8"/>
 </node>
 </node>
-<node TEXT="vorm tak" ID="ID_784697063" CREATED="1288536745875" MODIFIED="1289122245318" HGAP="21" VSHIFT="1">
-<node TEXT="Rechte lijn" ID="ID_884692926" CREATED="1288538234095" MODIFIED="1305276198448" HGAP="53" VSHIFT="-1">
+<node TEXT="vorm tak" ID="ID_784697063" CREATED="1288536745875" MODIFIED="1289122245318" HGAP_QUANTITY="21.0 px" VSHIFT_QUANTITY="1.0 px">
+<node TEXT="Rechte lijn" ID="ID_884692926" CREATED="1288538234095" MODIFIED="1305276198448" HGAP_QUANTITY="53.0 px" VSHIFT_QUANTITY="-1.0 px">
 <edge STYLE="linear" WIDTH="4"/>
-<hook NAME="FirstGroupNode"/>
 </node>
-<node TEXT="Bocht" ID="ID_609820168" CREATED="1288538240451" MODIFIED="1288539867421" HGAP="57" VSHIFT="9">
+<node TEXT="Bocht" ID="ID_609820168" CREATED="1288538240451" MODIFIED="1288539867421" HGAP_QUANTITY="57.0 px" VSHIFT_QUANTITY="9.0 px">
 <edge STYLE="bezier" WIDTH="4"/>
 </node>
-<node TEXT="Taps toelopend recht" ID="ID_1647821228" CREATED="1288538242377" MODIFIED="1288540221963" HGAP="60" VSHIFT="10">
+<node TEXT="Taps toelopend recht" ID="ID_1647821228" CREATED="1288538242377" MODIFIED="1288540221963" HGAP_QUANTITY="60.0 px" VSHIFT_QUANTITY="10.0 px">
 <edge STYLE="sharp_linear" WIDTH="4"/>
 </node>
-<node TEXT="Taps toelopend bocht" ID="ID_895403951" CREATED="1288538470332" MODIFIED="1288540434497" HGAP="70" VSHIFT="15">
+<node TEXT="Taps toelopend bocht" ID="ID_895403951" CREATED="1288538470332" MODIFIED="1288540434497" HGAP_QUANTITY="70.0 px" VSHIFT_QUANTITY="15.0 px">
 <edge STYLE="sharp_bezier" WIDTH="4"/>
 </node>
-<node TEXT="Verborgen tak" ID="ID_1675552701" CREATED="1288538507390" MODIFIED="1288548679856" HGAP="77" VSHIFT="18" BACKGROUND_COLOR="#00ffff">
+<node TEXT="Verborgen tak" ID="ID_1675552701" CREATED="1288538507390" MODIFIED="1288548679856" HGAP_QUANTITY="77.0 px" VSHIFT_QUANTITY="18.0 px" BACKGROUND_COLOR="#00ffff">
 <edge STYLE="hide_edge" WIDTH="4"/>
 </node>
 </node>
@@ -784,6 +795,7 @@
     </p>
   </body>
 </html>
+
 </richcontent>
 <edge STYLE="sharp_bezier" COLOR="#006633" WIDTH="2"/>
 <richcontent TYPE="NOTE">
@@ -808,7 +820,9 @@
 </html>
 </richcontent>
 </node>
-<node TEXT="Wolk" STYLE_REF="Reference" FOLDED="true" POSITION="right" ID="ID_1697684606" CREATED="1319873881764" MODIFIED="1323790359358" HGAP="550" VSHIFT="79"><richcontent TYPE="NOTE">
+<node TEXT="Wolk" STYLE_REF="Reference" FOLDED="true" POSITION="right" ID="ID_1697684606" CREATED="1319873881764" MODIFIED="1323790359358" HGAP_QUANTITY="550.0 px" VSHIFT_QUANTITY="79.0 px">
+<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1697684606" STARTINCLINATION="-90;73;" ENDINCLINATION="-90;73;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
+<richcontent TYPE="NOTE">
 
 <html>
   <head>
@@ -830,8 +844,7 @@
 </html>
 </richcontent>
 <hook NAME="FreeNode"/>
-<arrowlink SHAPE="CUBIC_CURVE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1697684606" STARTINCLINATION="-90;73;" ENDINCLINATION="-90;73;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
-<node TEXT="rechthoek" ID="ID_1198357672" CREATED="1305277572322" MODIFIED="1321038483416" HGAP="48" VSHIFT="4">
+<node TEXT="rechthoek" ID="ID_1198357672" CREATED="1305277572322" MODIFIED="1321038483416" HGAP_QUANTITY="48.0 px" VSHIFT_QUANTITY="4.0 px">
 <cloud COLOR="#f0f0f0" SHAPE="RECT"/>
 <richcontent TYPE="NOTE">
 
@@ -880,7 +893,7 @@
 </richcontent>
 </node>
 </node>
-<node TEXT="Relaties" POSITION="right" ID="ID_441663322" CREATED="1288536353356" MODIFIED="1321011073861" STYLE="fork" HGAP="-41" VSHIFT="37"><richcontent TYPE="NOTE">
+<node TEXT="Relaties" POSITION="right" ID="ID_441663322" CREATED="1288536353356" MODIFIED="1321011073861" STYLE="fork" HGAP_QUANTITY="-41.0 px" VSHIFT_QUANTITY="37.0 px"><richcontent TYPE="NOTE">
 
 <html>
   <head>
@@ -894,12 +907,12 @@
 </html>
 </richcontent>
 <cloud COLOR="#f0f0f0" SHAPE="ARC"/>
-<node TEXT="boven a" ID="ID_1863548649" CREATED="1288536207761" MODIFIED="1321011061055" HGAP="37" VSHIFT="-13" STYLE="bubble"/>
-<node TEXT="knoop a" ID="ID_1119041406" CREATED="1288535672221" MODIFIED="1336118905285" STYLE="bubble" HGAP="53" VSHIFT="7">
+<node TEXT="boven a" ID="ID_1863548649" CREATED="1288536207761" MODIFIED="1321011061055" HGAP_QUANTITY="37.0 px" VSHIFT_QUANTITY="-13.0 px" STYLE="bubble"/>
+<node TEXT="knoop a" ID="ID_1119041406" CREATED="1288535672221" MODIFIED="1336118905285" STYLE="bubble" HGAP_QUANTITY="53.0 px" VSHIFT_QUANTITY="7.0 px">
 <arrowlink SHAPE="CUBIC_CURVE" COLOR="#ff0000" WIDTH="5" TRANSPARENCY="80" FONT_SIZE="8" FONT_FAMILY="SansSerif" DESTINATION="ID_268922755" SOURCE_LABEL="ouder" TARGET_LABEL="kleinkind" MIDDLE_LABEL="hierarchie" STARTINCLINATION="-2;23;" ENDINCLINATION="-21;59;" STARTARROW="NONE" ENDARROW="NONE"/>
-<node TEXT="knoop b" ID="ID_1908863616" CREATED="1288535688688" MODIFIED="1321011087862" VGAP="0" VSHIFT="10" STYLE="bubble">
+<node TEXT="knoop b" ID="ID_1908863616" CREATED="1288535688688" MODIFIED="1321011087862" VGAP_QUANTITY="0.0 px" VSHIFT_QUANTITY="10.0 px" STYLE="bubble">
 <edge STYLE="bezier" WIDTH="thin"/>
-<node ID="ID_1947425814" CREATED="1319799725287" MODIFIED="1323790434784" HGAP="5" VSHIFT="-46" BACKGROUND_COLOR="#ffff99">
+<node ID="ID_1947425814" CREATED="1319799725287" MODIFIED="1323790434784" HGAP_QUANTITY="5.0 px" VSHIFT_QUANTITY="-46.0 px" BACKGROUND_COLOR="#ffff99">
 <icon BUILTIN="yes"/>
 <richcontent TYPE="NODE">
 
@@ -913,12 +926,13 @@
     </p>
   </body>
 </html>
+
 </richcontent>
+<arrowlink SHAPE="LINE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1947425814" STARTINCLINATION="4;47;" ENDINCLINATION="4;47;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
 <edge STYLE="hide_edge"/>
 <hook NAME="FreeNode"/>
-<arrowlink SHAPE="CUBIC_CURVE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1947425814" STARTINCLINATION="4;47;" ENDINCLINATION="4;47;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
 </node>
-<node ID="ID_1143366438" CREATED="1319799725287" MODIFIED="1323790424238" HGAP="105" VSHIFT="-21" BACKGROUND_COLOR="#ffff99">
+<node ID="ID_1143366438" CREATED="1319799725287" MODIFIED="1323790424238" HGAP_QUANTITY="105.0 px" VSHIFT_QUANTITY="-21.0 px" BACKGROUND_COLOR="#ffff99">
 <icon BUILTIN="yes"/>
 <richcontent TYPE="NODE">
 
@@ -932,13 +946,14 @@
     </p>
   </body>
 </html>
+
 </richcontent>
+<arrowlink SHAPE="LINE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1143366438" STARTINCLINATION="-41;22;" ENDINCLINATION="-41;22;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
 <font BOLD="false"/>
 <edge STYLE="hide_edge"/>
 <hook NAME="FreeNode"/>
-<arrowlink SHAPE="CUBIC_CURVE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1143366438" STARTINCLINATION="-41;22;" ENDINCLINATION="-41;22;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
 </node>
-<node TEXT="knoop c" FOLDED="true" ID="ID_268922755" CREATED="1288535699522" MODIFIED="1321011094420" VGAP="0" VSHIFT="10" TEXT_SHORTENED="true" STYLE="bubble"><richcontent TYPE="DETAILS">
+<node TEXT="knoop c" FOLDED="true" ID="ID_268922755" CREATED="1288535699522" MODIFIED="1321011094420" VGAP_QUANTITY="0.0 px" VSHIFT_QUANTITY="10.0 px" TEXT_SHORTENED="true" STYLE="bubble"><richcontent TYPE="DETAILS">
 
 <html>
   <head>
@@ -959,7 +974,7 @@
 </richcontent>
 <node TEXT="etc." ID="ID_1829616131" CREATED="1319919735822" MODIFIED="1319919743997"/>
 </node>
-<node STYLE_REF="Reference" ID="ID_389809087" CREATED="1319872918353" MODIFIED="1321039088884" HGAP="140" VSHIFT="79"><richcontent TYPE="NODE">
+<node STYLE_REF="Reference" ID="ID_389809087" CREATED="1319872918353" MODIFIED="1321039088884" HGAP_QUANTITY="140.0 px" VSHIFT_QUANTITY="79.0 px"><richcontent TYPE="NODE">
 
 <html>
   <head>
@@ -974,7 +989,9 @@
     </p>
   </body>
 </html>
+
 </richcontent>
+<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_389809087" STARTINCLINATION="-80;-24;" ENDINCLINATION="-80;-24;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
 <richcontent TYPE="NOTE">
 
 <html>
@@ -998,9 +1015,10 @@
 </richcontent>
 <hook NAME="FreeNode"/>
 <font BOLD="false"/>
-<arrowlink SHAPE="CUBIC_CURVE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_389809087" STARTINCLINATION="-80;-24;" ENDINCLINATION="-80;-24;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
 </node>
-<node TEXT="Label" STYLE_REF="Reference" ID="ID_1560136360" CREATED="1319872918353" MODIFIED="1321039208926" HGAP="0" VSHIFT="99"><richcontent TYPE="NOTE">
+<node TEXT="Label" STYLE_REF="Reference" ID="ID_1560136360" CREATED="1319872918353" MODIFIED="1321039208926" HGAP_QUANTITY="0.0 px" VSHIFT_QUANTITY="99.0 px">
+<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1560136360" STARTINCLINATION="-4;-35;" ENDINCLINATION="-4;-35;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
+<richcontent TYPE="NOTE">
 
 <html>
   <head>
@@ -1022,13 +1040,12 @@
 </html>
 </richcontent>
 <hook NAME="FreeNode"/>
-<arrowlink SHAPE="CUBIC_CURVE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1560136360" STARTINCLINATION="-4;-35;" ENDINCLINATION="-4;-35;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
 </node>
 </node>
 </node>
-<node TEXT="onder a" ID="ID_975219834" CREATED="1288536218798" MODIFIED="1321011102143" HGAP="27" VSHIFT="34" STYLE="bubble"/>
+<node TEXT="onder a" ID="ID_975219834" CREATED="1288536218798" MODIFIED="1321011102143" HGAP_QUANTITY="27.0 px" VSHIFT_QUANTITY="34.0 px" STYLE="bubble"/>
 </node>
-<node STYLE_REF="Reference" POSITION="right" ID="ID_1828022839" CREATED="1319963720129" MODIFIED="1321010997120" HGAP="524" VSHIFT="189"><richcontent TYPE="NODE">
+<node STYLE_REF="Reference" POSITION="right" ID="ID_1828022839" CREATED="1319963720129" MODIFIED="1321010997120" HGAP_QUANTITY="524.0 px" VSHIFT_QUANTITY="189.0 px"><richcontent TYPE="NODE">
 
 <html>
   <head>
@@ -1043,7 +1060,9 @@
     </p>
   </body>
 </html>
+
 </richcontent>
+<arrowlink SHAPE="LINE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1828022839" STARTINCLINATION="-46;-50;" ENDINCLINATION="-46;-50;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
 <hook NAME="FreeNode"/>
 <font BOLD="false"/>
 <richcontent TYPE="NOTE">
@@ -1067,9 +1086,8 @@
   </body>
 </html>
 </richcontent>
-<arrowlink SHAPE="CUBIC_CURVE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1828022839" STARTINCLINATION="-46;-50;" ENDINCLINATION="-46;-50;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
 </node>
-<node TEXT="Opmaken knoopkern" FOLDED="true" POSITION="left" ID="ID_1983670807" CREATED="1319795759589" MODIFIED="1321035141763" HGAP="10" VSHIFT="49" TEXT_SHORTENED="true"><richcontent TYPE="NOTE">
+<node TEXT="Opmaken knoopkern" FOLDED="true" POSITION="left" ID="ID_1983670807" CREATED="1319795759589" MODIFIED="1321035141763" HGAP_QUANTITY="10.0 px" VSHIFT_QUANTITY="49.0 px" TEXT_SHORTENED="true"><richcontent TYPE="NOTE">
 
 <html>
   <head>
@@ -1090,7 +1108,7 @@
   </body>
 </html>
 </richcontent>
-<node TEXT="Omlijnde knoopkern" ID="ID_1794331644" CREATED="1288536624648" MODIFIED="1321037674632" STYLE="bubble" VSHIFT="110"/>
+<node TEXT="Omlijnde knoopkern" ID="ID_1794331644" CREATED="1288536624648" MODIFIED="1321037674632" STYLE="bubble" VSHIFT_QUANTITY="110.0 px"/>
 <node TEXT="Kleur" ID="ID_1602479950" CREATED="1288536644733" MODIFIED="1321037781539">
 <node TEXT="Knoopkleur" ID="ID_1350125844" CREATED="1288536652401" MODIFIED="1321037697705" COLOR="#ff0066"/>
 <node TEXT="Knoopachtergrondkleur" ID="ID_113421480" CREATED="1288536658726" MODIFIED="1321037764067" BACKGROUND_COLOR="#00ff00"/>
@@ -1108,11 +1126,11 @@
 <font NAME="Dialog" SIZE="21"/>
 </node>
 </node>
-<node TEXT="Knipperen" ID="ID_1280590016" CREATED="1288548004325" MODIFIED="1321037796874" VSHIFT="-13">
+<node TEXT="Knipperen" ID="ID_1280590016" CREATED="1288548004325" MODIFIED="1321037796874" VSHIFT_QUANTITY="-13.0 px">
 <hook NAME="accessories/plugins/BlinkingNodeHook.properties"/>
 </node>
 </node>
-<node TEXT="Vrije + zwevende knoop" LOCALIZED_STYLE_REF="defaultstyle.floating" POSITION="left" ID="ID_188185624" CREATED="1319788879948" MODIFIED="1323789179419" HGAP="418" VSHIFT="72" TEXT_SHORTENED="true">
+<node TEXT="Vrije + zwevende knoop" LOCALIZED_STYLE_REF="defaultstyle.floating" POSITION="left" ID="ID_188185624" CREATED="1319788879948" MODIFIED="1323789179419" HGAP_QUANTITY="418.0 px" VSHIFT_QUANTITY="72.0 px" TEXT_SHORTENED="true">
 <hook NAME="FreeNode"/>
 <font BOLD="true"/>
 <richcontent TYPE="DETAILS">
@@ -1150,9 +1168,11 @@
 </html>
 </richcontent>
 </node>
-<node TEXT="Speciaal" POSITION="left" ID="ID_206364326" CREATED="1319795251644" MODIFIED="1321009985956" VSHIFT="20">
+<node TEXT="" POSITION="left" ID="ID_445314439" CREATED="1455910866417" MODIFIED="1455910866417">
 <hook NAME="FirstGroupNode"/>
-<node TEXT="Beveiligen met wachtwoord" ENCRYPTED_CONTENT="t/NS/HPSppU= VbQIDGWIdFE=" ID="ID_36040841" CREATED="1288542236861" MODIFIED="1321035430738" TEXT_SHORTENED="true" HGAP="30"><richcontent TYPE="NOTE">
+</node>
+<node TEXT="Speciaal" POSITION="left" ID="ID_206364326" CREATED="1319795251644" MODIFIED="1321009985956" VSHIFT_QUANTITY="20.0 px">
+<node TEXT="Beveiligen met wachtwoord" ENCRYPTED_CONTENT="t/NS/HPSppU= VbQIDGWIdFE=" ID="ID_36040841" CREATED="1288542236861" MODIFIED="1321035430738" TEXT_SHORTENED="true" HGAP_QUANTITY="30.0 px"><richcontent TYPE="NOTE">
 
 <html>
   <head>
@@ -1174,7 +1194,7 @@
 </html>
 </richcontent>
 </node>
-<node TEXT="Bereken = 4 + 3" ID="ID_49859005" CREATED="1319800320485" MODIFIED="1321035490783" HGAP="30" VSHIFT="10" TEXT_SHORTENED="true"><richcontent TYPE="NOTE">
+<node TEXT="Bereken = 4 + 3" ID="ID_49859005" CREATED="1319800320485" MODIFIED="1321035490783" HGAP_QUANTITY="30.0 px" VSHIFT_QUANTITY="10.0 px" TEXT_SHORTENED="true"><richcontent TYPE="NOTE">
 
 <html>
   <head>
@@ -1216,7 +1236,7 @@
 </richcontent>
 </node>
 </node>
-<node TEXT="Herinnering (Agenda)" ID="ID_1885496887" CREATED="1288542096079" MODIFIED="1321035618625" HGAP="31" VSHIFT="10" TEXT_SHORTENED="true">
+<node TEXT="Herinnering (Agenda)" ID="ID_1885496887" CREATED="1288542096079" MODIFIED="1321035618625" HGAP_QUANTITY="31.0 px" VSHIFT_QUANTITY="10.0 px" TEXT_SHORTENED="true">
 <hook NAME="plugins/TimeManagementReminder.xml">
     <Parameters REMINDUSERAT="2077460580480" PERIOD="1" UNIT="DAY"/>
 </hook>
@@ -1243,7 +1263,7 @@
 </richcontent>
 </node>
 </node>
-<node TEXT="Overig" POSITION="left" ID="ID_454770946" CREATED="1319875565802" MODIFIED="1321011282877" HGAP="10" VSHIFT="30">
+<node TEXT="Overig" POSITION="left" ID="ID_454770946" CREATED="1319875565802" MODIFIED="1321011282877" HGAP_QUANTITY="10.0 px" VSHIFT_QUANTITY="30.0 px">
 <node TEXT="Filter en sorteer" ID="ID_1987204825" CREATED="1319925023100" MODIFIED="1321035763908" TEXT_SHORTENED="true"><richcontent TYPE="NOTE">
 
 <html>
@@ -1302,6 +1322,7 @@
     </p>
   </body>
 </html>
+
 </richcontent>
 <richcontent TYPE="NOTE">
 
@@ -1338,6 +1359,7 @@
     </p>
   </body>
 </html>
+
 </richcontent>
 <richcontent TYPE="NOTE">
 
@@ -1360,7 +1382,9 @@
 <edge STYLE="horizontal"/>
 </node>
 </node>
-<node TEXT="Groepsknoop&#xa;met accollade" POSITION="left" ID="ID_499898058" CREATED="1319795597294" MODIFIED="1321037578474" HGAP="40">
+<node TEXT="" POSITION="left" ID="ID_1736833399" CREATED="1455910866421" MODIFIED="1455910866421">
+<hook NAME="SummaryNode"/>
+<node TEXT="Groepsknoop&#xa;met accollade" ID="ID_499898058" CREATED="1319795597294" MODIFIED="1321037578474" HGAP_QUANTITY="40.0 px">
 <font BOLD="true"/>
 <richcontent TYPE="NOTE">
 
@@ -1384,7 +1408,7 @@
 </html>
 </richcontent>
 <edge COLOR="#ff00ff" WIDTH="3"/>
-<hook NAME="SummaryNode"/>
+</node>
 </node>
 </node>
 </map>
