@@ -33,7 +33,6 @@ import java.util.TreeSet;
 import java.util.Vector;
 
 import javax.swing.ImageIcon;
-import javax.swing.ListCellRenderer;
 import javax.swing.tree.DefaultMutableTreeNode;
 
 import org.freeplane.core.io.IElementDOMHandler;
@@ -64,7 +63,6 @@ public class OptionPanelBuilder {
 		private final Vector<?> displayedItems;
 		private final String name;
 		private int verticalMargin;
-		private ListCellRenderer<?> renderer;
 		@SuppressWarnings("rawtypes")
 		private Class enumClass;
 
@@ -73,7 +71,6 @@ public class OptionPanelBuilder {
 			this.displayedItems = displayedItems;
 			this.name = name;
 			verticalMargin = 0;
-			renderer = null;
 		}
 
 		public IPropertyControl createControl() {
@@ -81,8 +78,6 @@ public class OptionPanelBuilder {
 			final ComboProperty comboProperty = enumClass != null ? ComboProperty.of(name, enumClass) : new ComboProperty(name, choices, displayedItems);
 			if(verticalMargin > 0)
 				comboProperty.setVerticalMargin(verticalMargin);
-			if(renderer != null)
-				comboProperty.setRenderer(renderer);
 			return comboProperty;
 		}
 
@@ -91,11 +86,6 @@ public class OptionPanelBuilder {
 			return this;
 		}
 
-		public ComboPropertyCreator withListCellRenderer(ListCellRenderer<?> createRenderer) {
-			this.renderer = createRenderer;
-			return this;
-		}
-
 		public ComboPropertyCreator withEnum(Class<?> enumClass) {
 			this.enumClass = enumClass;
 			return this;
