@@ -26,7 +26,7 @@ import java.awt.event.WindowAdapter;
 import java.awt.event.WindowEvent;
 
 import javax.swing.AbstractAction;
-import javax.swing.ImageIcon;
+import javax.swing.Icon;
 import javax.swing.JButton;
 import javax.swing.JCheckBox;
 import javax.swing.JDialog;
@@ -52,13 +52,13 @@ public class OptionalDontShowMeAgainDialog {
 	public final static int ONLY_OK_SELECTION_IS_STORED = 0;
 	public final static int ONLY_OK_SELECTION_IS_SHOWN = 2;
 
-	static public int show( final String pMessageId, final String pTitleId,
+	static public int show(final String pMessageId, final String pTitleId,
 	                       final String pPropertyName, final int pMessageType) {
 		return new OptionalDontShowMeAgainDialog(pMessageId, pTitleId, pPropertyName, pMessageType).show()
 		    .getResult();
 	}
 
-// // 	private final Controller controller;
+	// // 	private final Controller controller;
 	private JDialog mDialog;
 	private JCheckBox mDontShowAgainBox;
 	final private String mMessageId;
@@ -69,9 +69,9 @@ public class OptionalDontShowMeAgainDialog {
 	private int mResult = JOptionPane.CANCEL_OPTION;
 	final private String mTitleId;
 
-	private OptionalDontShowMeAgainDialog( final String pMessageId, final String pTitleId,
+	private OptionalDontShowMeAgainDialog(final String pMessageId, final String pTitleId,
 	                                      final String pPropertyName, final int pMessageType) {
-//		this.controller = controller;
+		//		this.controller = controller;
 		Controller controller = Controller.getCurrentController();
 		mParent = UITools.getCurrentFrame();
 		final IMapSelection selection = controller.getSelection();
@@ -137,20 +137,22 @@ public class OptionalDontShowMeAgainDialog {
 		mDialog.setDefaultCloseOperation(WindowConstants.DO_NOTHING_ON_CLOSE);
 		final AbstractAction cancelAction = new AbstractAction() {
 			/**
-			 * 
+			 *
 			 */
 			private static final long serialVersionUID = 1L;
 
+			@Override
 			public void actionPerformed(final ActionEvent pE) {
 				close(JOptionPane.CANCEL_OPTION);
 			}
 		};
 		final AbstractAction okAction = new AbstractAction() {
 			/**
-			 * 
+			 *
 			 */
 			private static final long serialVersionUID = 1L;
 
+			@Override
 			public void actionPerformed(final ActionEvent pE) {
 				close(JOptionPane.OK_OPTION);
 			}
@@ -167,11 +169,11 @@ public class OptionalDontShowMeAgainDialog {
 		    new JLabel(TextUtils.getText(mMessageId)),
 		    new GridBagConstraints(1, 0, 1, 1, 1.0, 1.0, GridBagConstraints.WEST, GridBagConstraints.BOTH, new Insets(
 		        5, 5, 0, 0), 0, 0));
-		final ImageIcon questionMark;
-		if(mMessageType == ONLY_OK_SELECTION_IS_SHOWN){
+		final Icon questionMark;
+		if (mMessageType == ONLY_OK_SELECTION_IS_SHOWN) {
 			questionMark = ResourceController.getResourceController().getIcon("/images/icons/messagebox_warning.png");
 		}
-		else{
+		else {
 			questionMark = ResourceController.getResourceController().getIcon("/images/icons/help.png");
 		}
 		mDialog.getContentPane().add(
@@ -192,10 +194,10 @@ public class OptionalDontShowMeAgainDialog {
 		    new GridBagConstraints(0, 2, 3, 1, 1.0, 1.0, GridBagConstraints.WEST, GridBagConstraints.BOTH, new Insets(
 		        5, 5, 0, 0), 0, 0));
 		final String okText;
-		if(mMessageType == ONLY_OK_SELECTION_IS_SHOWN){
+		if (mMessageType == ONLY_OK_SELECTION_IS_SHOWN) {
 			okText = TextUtils.getRawText("ok");
 		}
-		else{
+		else {
 			okText = TextUtils.getRawText("OptionalDontShowMeAgainDialog.ok");
 		}
 		final JButton okButton = new JButton(okText);
@@ -205,14 +207,16 @@ public class OptionalDontShowMeAgainDialog {
 		    okButton,
 		    new GridBagConstraints(2, 3, 1, 1, 1.0, 1.0, GridBagConstraints.WEST, GridBagConstraints.BOTH, new Insets(
 		        5, 5, 0, 0), 0, 0));
-		if(mMessageType != ONLY_OK_SELECTION_IS_SHOWN){
+		if (mMessageType != ONLY_OK_SELECTION_IS_SHOWN) {
 			final JButton cancelButton = new JButton(TextUtils.getRawText("OptionalDontShowMeAgainDialog.cancel"));
 			LabelAndMnemonicSetter.setLabelAndMnemonic(cancelButton, null);
 			cancelButton.addActionListener(cancelAction);
 			mDialog.getContentPane().add(
-				cancelButton,
-				new GridBagConstraints(3, 3, 1, 1, 1.0, 1.0, GridBagConstraints.WEST, GridBagConstraints.BOTH, new Insets(
-					5, 5, 0, 0), 0, 0));
+			    cancelButton,
+			    new GridBagConstraints(3, 3, 1, 1, 1.0, 1.0, GridBagConstraints.WEST, GridBagConstraints.BOTH,
+			        new Insets(
+			            5, 5, 0, 0),
+			        0, 0));
 		}
 		mDialog.getRootPane().setDefaultButton(okButton);
 		mDialog.pack();
