@@ -37,19 +37,18 @@ import java.awt.event.WindowEvent;
 import java.io.File;
 import java.net.URI;
 import java.net.URISyntaxException;
+import java.util.ArrayList;
 import java.util.List;
 import java.util.Set;
+import java.util.Vector;
 
 import javax.swing.Action;
 import javax.swing.ActionMap;
 import javax.swing.DefaultComboBoxModel;
-import javax.swing.DefaultListCellRenderer;
 import javax.swing.FocusManager;
-import javax.swing.Icon;
 import javax.swing.InputMap;
 import javax.swing.JComboBox;
 import javax.swing.JComponent;
-import javax.swing.JList;
 import javax.swing.JPopupMenu;
 import javax.swing.JScrollPane;
 import javax.swing.JSlider;
@@ -61,11 +60,16 @@ import javax.swing.SwingUtilities;
 
 import org.freeplane.core.resources.ResourceController;
 import org.freeplane.core.ui.AFreeplaneAction;
+import org.freeplane.core.ui.LengthUnits;
 import org.freeplane.core.ui.components.JComboBoxWithBorder;
+import org.freeplane.core.ui.components.RenderedContent;
 import org.freeplane.core.ui.components.UITools;
 import org.freeplane.core.undo.IActor;
+import org.freeplane.core.util.Quantity;
 import org.freeplane.core.util.TextUtils;
+import org.freeplane.features.DashVariant;
 import org.freeplane.features.link.ArrowType;
+import org.freeplane.features.link.ConnectorArrows;
 import org.freeplane.features.link.ConnectorModel;
 import org.freeplane.features.link.ConnectorModel.Shape;
 import org.freeplane.features.link.HyperTextLinkModel;
@@ -86,7 +90,6 @@ import org.freeplane.features.mode.Controller;
 import org.freeplane.features.mode.ModeController;
 import org.freeplane.features.spellchecker.mindmapmode.SpellCheckerController;
 import org.freeplane.features.styles.LogicalStyleKeys;
-import org.freeplane.features.url.UrlManager;
 
 /**
  * @author Dimitry Polivaev
@@ -141,6 +144,7 @@ public class MLinkController extends LinkController {
 		public void act() {
 			NodeLinks nodeLinks = NodeLinks.createLinkExtension(source);
 			arrowLink = new ConnectorModel(source, targetID,
+				getStandardConnectorArrows(), getStandardDashVariant().variant,
 				getStandardConnectorColor(), getStandardConnectorAlpha(),
 				getStandardConnectorShape(), getStandardConnectorWidth(),
 				getStandardLabelFontFamily(), getStandardLabelFontSize());
@@ -415,12 +419,12 @@ public class MLinkController extends LinkController {
 
 
 		AFreeplaneAction[] arrowActions = new AFreeplaneAction[]{
-                new ChangeConnectorArrowsAction(this, "none", link, ArrowType.NONE, ArrowType.NONE),
-                new ChangeConnectorArrowsAction(this, "forward", link, ArrowType.NONE, ArrowType.DEFAULT),
-                new ChangeConnectorArrowsAction(this, "backward", link, ArrowType.DEFAULT, ArrowType.NONE),
-                new ChangeConnectorArrowsAction(this, "both", link, ArrowType.DEFAULT, ArrowType.DEFAULT)
+                new ChangeConnectorArrowsAction(this, ConnectorArrows.NONE, link),
+                new ChangeConnectorArrowsAction(this, ConnectorArrows.FORWARD, link),
+                new ChangeConnectorArrowsAction(this, ConnectorArrows.BACKWARD, link),
+                new ChangeConnectorArrowsAction(this, ConnectorArrows.BOTH, link)
 		};
-        final JComboBox connectorArrows = createActionBox(arrowActions);
+        JComboBoxWithBorder connectorArrows = createActionBox(arrowActions);
 		addPopupComponent(arrowLinkPopup, TextUtils.getText("connector_arrows"), connectorArrows);
 
         final boolean twoNodesConnector = ! link.getSource().equals(link.getTarget());
@@ -440,17 +444,16 @@ public class MLinkController extends LinkController {
                     new ChangeConnectorShapeAction(this, link, Shape.LINEAR_PATH)
             };
         }
-            final JComboBox connectorShapes = createActionBox(shapeActions);
+            final JComboBoxWithBorder connectorShapes = createActionBox(shapeActions);
             addPopupComponent(arrowLinkPopup, TextUtils.getText("connector_shapes"), connectorShapes);
 
-        AFreeplaneAction[] dashActions = new AFreeplaneAction[] {
-                new ChangeConnectorDashAction(this, link, null),
-                new ChangeConnectorDashAction(this, link, new int[]{3, 3}),
-                new ChangeConnectorDashAction(this, link, new int[]{7, 7}),
-                new ChangeConnectorDashAction(this, link, new int[]{2, 7}),
-                new ChangeConnectorDashAction(this, link, new int[]{2, 7, 7, 7})
-        };
-        final JComboBox connectorDashes = createActionBox(dashActions);
+            
+        ArrayList<AFreeplaneAction> dashActions = new ArrayList<AFreeplaneAction>();
+        for (DashVariant  variant : DashVariant.values())
+        	dashActions.add(new ChangeConnectorDashAction(this, link, variant));
+        final JComboBoxWithBorder connectorDashes = createActionBox(dashActions.toArray(new AFreeplaneAction[dashActions.size()]));
+		final int verticalMargin = new Quantity<>(3, LengthUnits.pt).toBaseUnitsRounded();
+        connectorDashes.setVerticalMargin(verticalMargin);
         addPopupComponent(arrowLinkPopup, TextUtils.getText("connector_lines"), connectorDashes);
 
 		final SpinnerNumberModel widthModel = new SpinnerNumberModel(link.getWidth(),1, 32, 1);
@@ -557,35 +560,23 @@ public class MLinkController extends LinkController {
 	}
 
     @SuppressWarnings("serial")
-    protected JComboBox createActionBox(AFreeplaneAction[] items) {
-        final JComboBox box = new JComboBoxWithBorder();
+    protected JComboBoxWithBorder createActionBox(AFreeplaneAction[] items) {
+        final JComboBoxWithBorder box = new JComboBoxWithBorder();
         box.setEditable(false);
-        box.setModel(new DefaultComboBoxModel(items));
-        for(AFreeplaneAction item : items){
-            if(item.isSelected()){
+        Vector<RenderedContent<AFreeplaneAction>> renderedContent = RenderedContent.of(items);
+		box.setModel(new DefaultComboBoxModel<>(renderedContent));
+        for(RenderedContent<AFreeplaneAction> item : renderedContent){
+            if(item.value.isSelected()){
                 box.setSelectedItem(item);
                 break;
             }
         }
-        box.setRenderer(new DefaultListCellRenderer() {
-            @Override
-            public Component getListCellRendererComponent(JList list, Object value, int index, boolean isSelected,
-                                                          boolean cellHasFocus) {
-                Action action = (Action) value;
-                Icon icon = (Icon)action.getValue(Action.SMALL_ICON);
-                String text = (String)action.getValue(Action.NAME);
-                Object renderedValue = text == null ? icon : text;
-                DefaultListCellRenderer renderer = (DefaultListCellRenderer) super.getListCellRendererComponent(list, renderedValue, index, isSelected, cellHasFocus);
-                if(text != null && icon != null)
-                    renderer.setIcon(icon);
-                return renderer;
-            }
-        });
+        box.setRenderer(RenderedContent.createRenderer());
         box.addItemListener(new ItemListener() {
             public void itemStateChanged(ItemEvent e) {
-                AFreeplaneAction item = (AFreeplaneAction)e.getItem();
+            	RenderedContent<AFreeplaneAction> item = (RenderedContent<AFreeplaneAction>)e.getItem();
                 final JComboBox box = (JComboBox) e.getSource();
-                item.actionPerformed(new ActionEvent(box, ActionEvent.ACTION_PERFORMED, null));
+                item.value.actionPerformed(new ActionEvent(box, ActionEvent.ACTION_PERFORMED, null));
             }
         });
         return box;
@@ -998,12 +989,6 @@ public class MLinkController extends LinkController {
 		Controller.getCurrentModeController().execute(actor, connector.getSource().getMap());
 	}
 
-	@Override
-    @SuppressWarnings("deprecation")
-    public void loadURI(URI uri) {
-		UrlManager.getController().loadURL(uri);
-    }
-
 	@Override
 	protected void loadURL(final NodeModel node, final ActionEvent e) {
 		// load as documentation map if the node belongs to a documentation map
@@ -1022,6 +1007,22 @@ public class MLinkController extends LinkController {
 		}
 	}
 
+	public void loadURI(NodeModel node, URI uri) {
+		// load as documentation map if the node belongs to a documentation map
+		boolean addDocuMapAttribute = node.getMap().containsExtension(DocuMapAttribute.class)
+				&& ! modeController.containsExtension(DocuMapAttribute.class);
+		if(addDocuMapAttribute){
+			modeController.addExtension(DocuMapAttribute.class, DocuMapAttribute.instance);
+		}
+		try{
+			loadURI(uri);
+		}
+		finally{
+			if(addDocuMapAttribute){
+				modeController.removeExtension(DocuMapAttribute.class);
+			}
+		}
+	}
 	public String getAnchorID() {
 		return anchorID;
 	}
