@@ -65,6 +65,7 @@ public class NodeModel{
 	public final static int UNKNOWN_POSITION = 0;
 	static public final Object UNKNOWN_PROPERTY = new Object();
 	public static final String NODE_ICON = "icon";
+	public static final String NODE_ICON_SIZE = "icon_size";
 	static public final Object HYPERLINK_CHANGED = "hyperlink_changed";
 
 	private final List<NodeModel> children;
@@ -486,8 +487,7 @@ public class NodeModel{
 	public void setLeft(final boolean isLeft) {
 		position = isLeft ? NodeModel.LEFT_POSITION : NodeModel.RIGHT_POSITION;
 		if (!isRoot()) {
-			for (int i = 0; i < getChildCount(); i++) {
-				final NodeModel child = getChildAt(i);
+			for (final NodeModel child : children) {
 				if (child.position != position) {
 					child.setLeft(isLeft);
 				}
@@ -499,7 +499,7 @@ public class NodeModel{
 	 */
 	public void setMap(final MapModel map) {
 		this.map = map;
-		for (final NodeModel child : getChildrenInternal()) {
+		for (final NodeModel child : children) {
 			child.setMap(map);
 		}
 	}
@@ -507,7 +507,8 @@ public class NodeModel{
 	public void setParent(final NodeModel newParent) {
 		if(parent == null && newParent != null && newParent.isAttached())
 	        attach();
-		else if(parent != null && parent.isAttached() &&  (newParent == null || !newParent.isAttached()))
+		else if(parent != null && parent.isAttached() &&  (newParent == null || !newParent.isAttached())
+				|| newParent == null && isAttached())
 	        detach();
 		parent = newParent;
 	}
