@@ -22,7 +22,7 @@ package org.freeplane.features.note;
 import java.awt.Color;
 import java.awt.Component;
 import java.awt.Font;
-import java.net.URL;
+import javax.swing.Icon;
 
 import org.freeplane.core.extension.IExtension;
 import org.freeplane.core.io.WriteManager;
@@ -42,21 +42,29 @@ import org.freeplane.features.nodestyle.NodeStyleController;
 import org.freeplane.features.styles.MapStyle;
 import org.freeplane.features.styles.MapStyleModel;
 import org.freeplane.features.text.TextController;
+import org.freeplane.view.swing.map.MainView;
 
 /**
  * @author Dimitry Polivaev
  */
 public class NoteController implements IExtension {
-	private static boolean firstRun = true;
 	/**
 	 *
 	 */
 	public static final String NODE_NOTE_ICON = "accessories.plugins.NodeNoteIcon";
-	private static UIIcon noteIcon;
-	public static URL bwNoteIconUrl;
+	private static final UIIcon noteIcon= IconStoreFactory.ICON_STORE.getUIIcon("knotes.png");
+	public static final String bwNoteIconUrl;
+	public static final Icon bwNoteIcon;
+	
+	static {
+			String bwNoteIconName = "note_black_and_transp.png";
+			bwNoteIconUrl = "freeplaneresource:/images/" + bwNoteIconName;
+			bwNoteIcon = IconStoreFactory.ICON_STORE.getUIIcon(bwNoteIconName).getIcon();
+	}
 	public static final String SHOW_NOTE_ICONS = "show_note_icons";
 	private static final Integer NOTE_TOOLTIP = 9;
 	public static final String SHOW_NOTES_IN_MAP = "show_notes_in_map";
+	protected static final String SHOW_NOTE_ICON_IN_TOOLTIP = "show_note_icon_in_tooltip";
 
 	public static NoteController getController() {
 		final ModeController modeController = Controller.getCurrentModeController();
@@ -70,11 +78,6 @@ public class NoteController implements IExtension {
 	public static void install( final NoteController noteController) {
 		final ModeController modeController = Controller.getCurrentModeController();
 		modeController.addExtension(NoteController.class, noteController);
-		if (firstRun) {
-			noteIcon = IconStoreFactory.create().getUIIcon("knotes.png");
-			bwNoteIconUrl = ResourceController.getResourceController().getResource("/images/note_black_and_transp.png");
-			firstRun = false;
-		}
 	}
 
  	final private ModeController modeController;
@@ -110,20 +113,26 @@ public class NoteController implements IExtension {
 
 	private void registerNoteTooltipProvider(ModeController modeController) {
 		modeController.addToolTipProvider(NOTE_TOOLTIP, new ITooltipProvider() {
-			public String getTooltip(ModeController modeController, NodeModel node, Component view) {
+			public String getTooltip(final ModeController modeController, NodeModel node, Component view){
+				return getTooltip(modeController, node, (MainView)view);
+			}
+			private String getTooltip(final ModeController modeController, NodeModel node, MainView view) {
 				if(showNotesInMap(node.getMap()) && ! TextController.getController(modeController).isMinimized(node)){
 					return null;
 				}
 				final String noteText = NoteModel.getNoteText(node);
 				if (noteText == null)
 					return null;
-				final String rule = getNoteCSSStyle(modeController, node, true);
+				float zoom = view.getNodeView().getMap().getZoom();
+				final String rule = getNoteCSSStyle(modeController, node, zoom, true);
 				final StringBuilder tooltipBodyBegin = new StringBuilder("<body><div style=\"");
 				tooltipBodyBegin.append(rule);
 				tooltipBodyBegin.append("\">");
-				tooltipBodyBegin.append("<img src =\"");
-				tooltipBodyBegin.append(bwNoteIconUrl.toString());
-				tooltipBodyBegin.append("\">");
+				if(ResourceController.getResourceController().getBooleanProperty(SHOW_NOTE_ICON_IN_TOOLTIP)) {
+					tooltipBodyBegin.append("<img src =\"");
+					tooltipBodyBegin.append(bwNoteIconUrl.toString());
+					tooltipBodyBegin.append("\">");
+				}
 				final String tooltipText = noteText.replaceFirst("<body>", 
 					tooltipBodyBegin.toString()).replaceFirst("</body>", "</div></body>");
 				return tooltipText;
@@ -143,6 +152,11 @@ public class NoteController implements IExtension {
 				}
 				return null;
 			}
+
+			@Override
+			public boolean mustIncludeInIconRegistry() {
+				return true;
+			}
 		});
     }
 
@@ -151,7 +165,7 @@ public class NoteController implements IExtension {
 		return Boolean.parseBoolean(property);
 	}
 
-	protected String getNoteCSSStyle(ModeController modeController, NodeModel node, boolean asHtmlFragment) {
+	protected String getNoteCSSStyle(ModeController modeController, NodeModel node, float zoom, boolean asHtmlFragment) {
 		final StringBuilder rule = new StringBuilder();
 		// set default font for notes:
 		final NodeStyleController style = (NodeStyleController) Controller.getCurrentModeController().getExtension(
@@ -163,7 +177,7 @@ public class NoteController implements IExtension {
 		    final Font noteFont = style.getFont(noteStyleNode);
 		    Color noteBackground = style.getBackgroundColor(noteStyleNode);
 		    Color noteForeground = style.getColor(noteStyleNode);
-		    final int alignment = style.getTextAlign(noteStyleNode).swingConstant;
+		    final int alignment = style.getHorizontalTextAlignment(noteStyleNode).swingConstant;
 		    final CssRuleBuilder cssRuleBuilder = new CssRuleBuilder();
 		    if(asHtmlFragment)
 		    	cssRuleBuilder.withHTMLFont(noteFont);
@@ -173,7 +187,7 @@ public class NoteController implements IExtension {
 					.withBackground(noteBackground)
 					.withAlignment(alignment);
 		    if(asHtmlFragment)
-		    	cssRuleBuilder.withMaxWidthAsPt(NodeSizeModel.getMaxNodeWidth(noteStyleNode), style.getMaxWidth(node));
+		    	cssRuleBuilder.withMaxWidthAsPt(zoom, NodeSizeModel.getMaxNodeWidth(noteStyleNode), style.getMaxWidth(node));
 			rule.append(cssRuleBuilder);
 		}
 		return rule.toString();
