@@ -196,7 +196,6 @@ public class MLogicalStyleController extends LogicalStyleController {
 
 // 	private final ModeController modeController;
 	final private List<AssignStyleAction> actions;
-	private FilterComposerDialog filterComposerDialog;
 
 	public MLogicalStyleController(ModeController modeController) {
 		super(modeController);
@@ -520,26 +519,6 @@ public class MLogicalStyleController extends LogicalStyleController {
 			}
 		};
 	}
-
-	public FilterComposerDialog getFilterComposerDialog() {
-		if(filterComposerDialog == null){
-			filterComposerDialog = new FilterComposerDialog();
-			Controller.getCurrentController().getMapViewManager().addMapSelectionListener(filterComposerDialog);
-		}
-		return filterComposerDialog;
-    }
-	
-	public ASelectableCondition editCondition(ASelectableCondition value) {
-	    final FilterComposerDialog filterComposerDialog = getFilterComposerDialog();
-	    filterComposerDialog.acceptMultipleConditions(true);
-	    if(value != null)
-	    	filterComposerDialog.addCondition(value);
-	    filterComposerDialog.show();
-	    List<ASelectableCondition> conditions = filterComposerDialog.getConditions();
-	    if(filterComposerDialog.isSuccess())
-	    	return conditions.isEmpty() ? null : conditions.get(0);
-	    return value;
-    }
     
 
 }
