@@ -164,6 +164,7 @@ public class FreeplaneGUIStarter implements FreeplaneStarter {
 		try {
 			Controller controller = new Controller(applicationResourceController);
 			Controller.setCurrentController(controller);
+			Compat.macAppChanges();
 			controller.addAction(new QuitAction());
 			applicationResourceController.init();
 			LogUtils.createLogger();
@@ -208,7 +209,7 @@ public class FreeplaneGUIStarter implements FreeplaneStarter {
 			TextController.install();
 			TimeController.install();
 			LinkController.install();
-			IconController.install();
+			IconController.installConditionControllers();
 			HelpController.install();
 			controller.addAction(new NextNodeAction(Direction.FORWARD));
 			controller.addAction(new NextNodeAction(Direction.BACK));
@@ -226,7 +227,6 @@ public class FreeplaneGUIStarter implements FreeplaneStarter {
 			if(freeplaneSurveyProperties.mayAskUserToFillSurveys()) {
 				controller.addApplicationLifecycleListener(new SurveyStarter(freeplaneSurveyProperties, new SurveyRunner(freeplaneSurveyProperties), Math.random()));
 			}
-			Compat.macAppChanges();
 			return controller;
 		}
 		catch (final Exception e) {
