@@ -1199,13 +1199,13 @@ public class NodeView extends JComponent implements INodeView {
 		for (final ListIterator<NodeView> e = getChildrenViews().listIterator(); e.hasNext();) {
 			e.next().remove();
 		}
-		getMap().deselect(this);
 		getMap().getModeController().onViewRemoved(this);
 		removeFromMap();
 		if (attributeView != null) {
 			attributeView.viewRemoved();
 		}
 		getModel().removeViewer(this);
+		getMap().deselect(this);
 	}
 
 	protected void removeFromMap() {
@@ -1392,7 +1392,7 @@ public class NodeView extends JComponent implements INodeView {
 		final ModeController modeController = map.getModeController();
         final NodeStyleController nsc = NodeStyleController.getController(modeController);
         final int minNodeWidth = map.getZoomed(nsc.getMinWidth(getModel()).toBaseUnits());
-        final int maxNodeWidth = map.getZoomed(nsc.getMaxWidth(getModel()).toBaseUnits());
+        final int maxNodeWidth = Math.max(map.getLayoutSpecificMaxNodeWidth(), map.getZoomed(nsc.getMaxWidth(getModel()).toBaseUnits()));
         mainView.setMinimumWidth(minNodeWidth);
         mainView.setMaximumWidth(maxNodeWidth);
 
